==> touhoulittlemaid-fabric-1.21.1-0.0.3-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/task/meal/DefaultMaidHealSelfMeal.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.task.meal;

import com.github.tartaricacid.touhoulittlemaid.api.task.meal.IMaidMeal;
import com.github.tartaricacid.touhoulittlemaid.config.subconfig.MaidConfig;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.event.MaidMealRegConfigEvent;
import com.github.tartaricacid.touhoulittlemaid.network.NetworkHandler;
import com.github.tartaricacid.touhoulittlemaid.network.message.SpawnParticlePackage;
import net.minecraft.class_1268;
import net.minecraft.class_1799;
import net.minecraft.class_4174;
import net.minecraft.class_9334;

public class DefaultMaidHealSelfMeal implements IMaidMeal {
    private static final int MAX_PROBABILITY = 5;

    @Override
    public boolean canMaidEat(EntityMaid maid, class_1799 stack, class_1268 hand) {
        return stack.method_57824(class_9334.field_50075) != null && !IMaidMeal.isBlockList(stack, MaidConfig.MAID_HEAL_MEALS_BLOCK_LIST.get())
                && !IMaidMeal.isBlockList(stack, MaidMealRegConfigEvent.HEAL_MEAL_REGEX);
    }

    @Override
    public void onMaidEat(EntityMaid maid, class_1799 stack, class_1268 hand) {
        //FoodProperties foodProperties = stack.getFoodProperties(maid);
        class_4174 foodProperties = stack.method_57824(class_9334.field_50075);
        if (foodProperties != null) {
            maid.method_6019(hand);
            int nutrition = foodProperties.comp_2491();
            float saturation = foodProperties.comp_2492();
            // 1.21 修改了营养值数值大小和相关计算，删去了 saturationModifier，改为直接加和
            float total = nutrition + saturation;
            // 原版的熟牛肉之类的一般在 20 左右（除了迷之炖菜为 34.2）
            if (maid.method_59922().method_43048(MAX_PROBABILITY) < total) {
                float healCount = Math.max(total / MAX_PROBABILITY, 1);
                maid.method_6025(healCount);
                NetworkHandler.sendToNearby(maid, new SpawnParticlePackage(maid.method_5628(), SpawnParticlePackage.Type.HEAL, stack.method_7935(maid)));
            }
        }
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.2.0-neo1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/entity/task/meal/DefaultMaidHealSelfMeal.java <==
package com.github.tartaricacid.touhoulittlemaid.entity.task.meal;

import com.github.tartaricacid.touhoulittlemaid.api.task.meal.IMaidMeal;
import com.github.tartaricacid.touhoulittlemaid.api.task.meal.MaidMealType;
import com.github.tartaricacid.touhoulittlemaid.config.subconfig.MaidConfig;
import com.github.tartaricacid.touhoulittlemaid.entity.passive.EntityMaid;
import com.github.tartaricacid.touhoulittlemaid.event.MaidMealRegConfigEvent;
import com.github.tartaricacid.touhoulittlemaid.network.NetworkHandler;
import com.github.tartaricacid.touhoulittlemaid.network.message.SpawnParticlePackage;
import net.minecraft.class_1268;
import net.minecraft.class_1799;
import net.minecraft.class_4174;
import net.minecraft.class_9334;

public class DefaultMaidHealSelfMeal implements IMaidMeal {
    private static final int MAX_PROBABILITY = 5;

    @Override
    public boolean canMaidEat(EntityMaid maid, class_1799 stack, class_1268 hand) {
        return stack.method_57824(class_9334.field_50075) != null && !IMaidMeal.isBlockList(stack, MaidConfig.MAID_HEAL_MEALS_BLOCK_LIST.get())
                && !IMaidMeal.isBlockList(stack, MaidMealRegConfigEvent.HEAL_MEAL_REGEX);
    }

    @Override
    public void onMaidEat(EntityMaid maid, class_1799 stack, class_1268 hand) {
        //FoodProperties foodProperties = stack.getFoodProperties(maid);
        class_4174 foodProperties = stack.method_57824(class_9334.field_50075);
        if (foodProperties != null) {
            // 调用饰品
            maid.getMaidBauble().fireEvent((b, s) -> {
                b.onMaidEat(maid, s, stack, MaidMealType.HEAL_MEAL);
                return false;
            });

            maid.method_6019(hand);
            int nutrition = foodProperties.comp_2491();
            float saturation = foodProperties.comp_2492();
            // 1.21 修改了营养值数值大小和相关计算，删去了 saturationModifier，改为直接加和
            float total = nutrition + saturation;
            // 原版的熟牛肉之类的一般在 20 左右（除了迷之炖菜为 34.2）
            if (maid.method_59922().method_43048(MAX_PROBABILITY) < total) {
                float healCount = Math.max(total / MAX_PROBABILITY, 1);
                maid.method_6025(healCount);
                NetworkHandler.sendToNearby(maid, new SpawnParticlePackage(maid.method_5628(), SpawnParticlePackage.Type.HEAL, stack.method_7935(maid)));
            }
        }
    }
}
